==> dde-session-shell_5.5.66.orig.tar.xz: dde-session-shell-5.5.66/translations/dde-session-shell_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifica il tuo Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID bloccato, utilizza la password per cortesia</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifica la tua impronta digitale</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Sblocco con impronta bloccato, utilizza la password</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifica il tuo Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID bloccato, utilizza la password per cortesia</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Password errata</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Riprova tra %n minuti</numerusform><numerusform>Riprova tra %n minuti</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Password dimenticata?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Riprova tra %n minuti</numerusform><numerusform>Riprova tra %n minuti</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Password dimenticata?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN errato</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey richiesta</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Inserisci il PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Riprova tra %n minuto(i)</numerusform><numerusform>Riprova tra %n minuto(i)</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Riprova tra %n minuti</numerusform><numerusform>Riprova tra %n minuti</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>La tua password scadrà in %n giorni, ricordati di sostituirla</numerusform><numerusform>La tua password scadrà in %n giorni, ricordati di sostituirla</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Password scaduta, cambiala per cortesia</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Account errato</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Password errata</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Schermata di blocco</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Blocco schermo fallito</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Verifica dell&apos;impronta digitale fallita per timeout, inserisci la tua password manualmente</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Controllo impronta digitale fallita</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Gli utenti sopra indicati sono oggati ed i dati andranno persi spegnendo il PC, sicuro di voler spegnere?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Gli utenti sopra indicati sono loggati ed i dati andranno persi col riavvio, sicuro di voler riavviare?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Hai abilitato il livello di sicurezza elevato del sistema, quindi non puoi passare alla modalità Wayland, disabilita il livello di sicurezza elevato in Centro sicurezza e riprova.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambia utente</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Cambia Sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Avvia il System Monitor</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>I programmi non permettono lo spegnimento del computer, forzando lo spegnimento potresti perdere dati.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Per chiudere il programma, clicca Annulla, e chiudi il programma in questione.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>I programmi non permettono il riavvio del computer, forzando il riavvio potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>I programmi non permettono la sospensione del computer, forzando la sospensione potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>I programmi non permettono l&apos;ibernazione del computer, forzando l&apos;ibernazione potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>I programmi non permettono il logout dal computer, forzando il logout potresti perdere dati.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Sicuro di voler spegnere?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Desideri veramente riavviare il Sistema?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sicuro di voler terminare la sessione?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.86.orig.tar.xz: dde-session-shell-5.5.86/translations/dde-session-shell_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifica il tuo Face ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID bloccato, utilizza la password per cortesia</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Dispositivo non disponibile!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifica la tua impronta digitale</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Sblocco con impronta bloccato, utilizza la password</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifica il tuo Iris ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID bloccato, utilizza la password per cortesia</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Password errata</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Password dimenticata?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Riprova tra %n minuti</numerusform><numerusform>Riprova tra %n minuti</numerusform><numerusform>Riprova tra %n minuti</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Reset password</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Password dimenticata?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifica completata con successo</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform><numerusform>Verifica fallita, %n tentativi rimanenti</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifica fallita, un solo tentativo rimanente</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN errato</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey richiesta</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Inserisci il PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Riprova tra %n minuto(i)</numerusform><numerusform>Riprova tra %n minuto(i)</numerusform><numerusform>Riprova tra %n minuto(i)</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Riprova tra 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Password scaduta, cambiala per cortesia</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Account errato</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Password errata</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Schermata di blocco</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Blocco schermo fallito</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Verifica dell&apos;impronta digitale fallita per timeout, inserisci la tua password manualmente</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Controllo impronta digitale fallita</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Gli utenti sopra indicati sono oggati ed i dati andranno persi spegnendo il PC, sicuro di voler spegnere?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Gli utenti sopra indicati sono loggati ed i dati andranno persi col riavvio, sicuro di voler riavviare?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Hai abilitato il livello di sicurezza elevato del sistema, quindi non puoi passare alla modalità Wayland, disabilita il livello di sicurezza elevato in Centro sicurezza e riprova.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Blocca</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Cambia utente</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Cambia Sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Avvia il System Monitor</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>I programmi non permettono lo spegnimento del computer, forzando lo spegnimento potresti perdere dati.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Per chiudere il programma, clicca Annulla, e chiudi il programma in questione.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>I programmi non permettono il riavvio del computer, forzando il riavvio potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>I programmi non permettono la sospensione del computer, forzando la sospensione potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>I programmi non permettono l&apos;ibernazione del computer, forzando l&apos;ibernazione potresti perdere dati.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>I programmi non permettono il logout dal computer, forzando il logout potresti perdere dati.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Spegni</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ibernazione</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Logout</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Sicuro di voler spegnere?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Desideri veramente riavviare il Sistema?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sicuro di voler terminare la sessione?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Attiva</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Disattiva</translation>
    </message>
</context>
</TS>
